"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
/* eslint-disable no-console */

const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);
function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initHighlighter = async () => {
      try {
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        _log('Initializing with themes:', initialThemes.map(t => t.name));

        // First create the highlighter with the themes
        const highlighterInstance = await (0, _core.createHighlighterCore)({
          langs: initialLanguages,
          themes: initialThemes
        });

        // Then load all themes one by one
        for (const theme of initialThemes) {
          highlighterInstance.loadThemeSync([theme]);
        }

        // Set the first theme as default if available
        const firstTheme = initialThemes[0];
        if (firstTheme) {
          highlighterInstance.setTheme(firstTheme);
          _log('Default theme set:', firstTheme.name);
        }

        // Load languages sequentially to avoid race conditions
        for (const lang of initialLanguages) {
          highlighterInstance.loadLanguageSync([lang]);
        }
        _log('Initialization complete', {
          languages: highlighterInstance.getLoadedLanguages(),
          themes: highlighterInstance.getLoadedThemes()
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map